@@ -786,9 +786,9 @@ static char *Oops_eip(const char *line, char ***string, int string_max,
     /* Oops 'EIP:' line for other architectures */
     RE_COMPILE(&re_Oops_eip_other,
 		"^("
-    /* i386 */	  "EIP: +.*"
-    /* m68k */	  "|PC *= *"
-    /* arm */	  "|pc *: *"
+    		  "EIP: +.*"	/* i386 */
+    		  "|PC *= *"	/* m68k, alpha */
+    		  "|pc *: *"	/* arm */
 		")"
 		BRACKETED_ADDRESS
 		,
@@ -808,6 +808,86 @@ static char *Oops_eip(const char *line, char ***string, int string_max,
     return(NULL);
 }
 
+/* Look for the arm lr line, returns start of the relevant hex value */
+static char *Oops_arm_lr(const char *line, char ***string, int string_max)
+{
+    int i;
+    static regex_t     re_Oops_arm_lr;
+    static regmatch_t *re_Oops_arm_lr_pmatch;
+    static const char procname[] = "Oops_arm_lr";
+
+    RE_COMPILE(&re_Oops_arm_lr,
+	    "pc *: *" BRACKETED_ADDRESS		/* 1 */
+	    " *lr *: *" BRACKETED_ADDRESS,	/* 2 */
+	REG_NEWLINE|REG_EXTENDED|REG_ICASE,
+	&re_Oops_arm_lr_pmatch);
+
+    i = regexec(&re_Oops_arm_lr, line, re_Oops_arm_lr.re_nsub+1,
+	re_Oops_arm_lr_pmatch, 0);
+    DEBUG(4, "regexec %d", i);
+    if (i == 0) {
+	re_string_check(re_Oops_arm_lr.re_nsub+1, string_max, procname);
+	re_strings(&re_Oops_arm_lr, line, re_Oops_arm_lr_pmatch,
+	    string);
+	return((*string)[re_Oops_arm_lr.re_nsub]);
+    }
+    return(NULL);
+}
+
+/* Set the arm lr from the lr line */
+static void Oops_set_arm_lr(const char *value, SYMBOL_SET *ss)
+{
+    static const char procname[] = "Oops_set_arm_lr";
+    addr_t ra;
+    ra = hexstring(value);
+    if (errno) {
+	ERROR(" Invalid hex value in ra line, ignored - '%s'", value);
+	perror(prefix);
+	ra = 0;
+    }
+    add_symbol_n(ss, ra, 'R', 1, ">>LR; ");
+}
+
+/* Look for the alpha ra line, returns start of the relevant hex value */
+static char *Oops_alpha_ra(const char *line, char ***string, int string_max)
+{
+    int i;
+    static regex_t     re_Oops_alpha_ra;
+    static regmatch_t *re_Oops_alpha_ra_pmatch;
+    static const char procname[] = "Oops_alpha_ra";
+
+    RE_COMPILE(&re_Oops_alpha_ra,
+	    "pc *= *" BRACKETED_ADDRESS		/* 1 */
+	    " *ra *= *" BRACKETED_ADDRESS,	/* 2 */
+	REG_NEWLINE|REG_EXTENDED|REG_ICASE,
+	&re_Oops_alpha_ra_pmatch);
+
+    i = regexec(&re_Oops_alpha_ra, line, re_Oops_alpha_ra.re_nsub+1,
+	re_Oops_alpha_ra_pmatch, 0);
+    DEBUG(4, "regexec %d", i);
+    if (i == 0) {
+	re_string_check(re_Oops_alpha_ra.re_nsub+1, string_max, procname);
+	re_strings(&re_Oops_alpha_ra, line, re_Oops_alpha_ra_pmatch,
+	    string);
+	return((*string)[re_Oops_alpha_ra.re_nsub]);
+    }
+    return(NULL);
+}
+
+/* Set the alpha ra from the ra line */
+static void Oops_set_alpha_ra(const char *value, SYMBOL_SET *ss)
+{
+    static const char procname[] = "Oops_set_alpha_ra";
+    addr_t ra;
+    ra = hexstring(value);
+    if (errno) {
+	ERROR(" Invalid hex value in ra line, ignored - '%s'", value);
+	perror(prefix);
+	ra = 0;
+    }
+    add_symbol_n(ss, ra, 'R', 1, ">>RA; ");
+}
+
 /* Look for the alpha spinlock stuck line, returns TRUE with string[1]
  * containing the PC, string[2] containing the previous PC.
  */
@@ -1332,16 +1412,21 @@ static const char *Oops_i370_regs(const char *line)
 
     /* Matching "oR10: unbracketed address" enables us to also match a
        CRIS register dump for the lines that overlap with the i370
-       register dump format.  */
+       register dump format. This can match arm lines by mistake, check
+       for a second register after the address.  Only if the second register
+       is missing is this i370/cris.  */
     RE_COMPILE(&re_Oops_i370_regs,
-	    "^(o?r[0-9]{1,2}): *" UNBRACKETED_ADDRESS,	/* 1, 2 */
+	    "^(o?r[0-9]{1,2}): *"	/* 1 */
+	    UNBRACKETED_ADDRESS		/* 2 */
+	    "( *r[0-9]{1,2})?"		/* 3 */
+	    ,
 	REG_NEWLINE|REG_EXTENDED|REG_ICASE,
 	&re_Oops_i370_regs_pmatch);
 
     i = regexec(&re_Oops_i370_regs, line, re_Oops_i370_regs.re_nsub+1,
 	re_Oops_i370_regs_pmatch, 0);
     DEBUG(4, "regexec %d", i);
-    if (i == 0)
+    if (i == 0 && re_Oops_i370_regs_pmatch[3].rm_so == -1)
 	return(line + re_Oops_i370_regs_pmatch[0].rm_so);
     return(NULL);
 }
@@ -1548,6 +1633,7 @@ static int Oops_print(const char *line, const char **text, char ***string,
 	    "|[^ ]{3} [ 0-9][0-9] [0-9]{2}:[0-9]{2}:[0-9]{2} "
 	      "[^ ]+ kernel: +"		/* syslogd */
 	    "|<[0-9]+>"			/* kmsg */
+	    "|[0-9]+\\|[^|]+\\|[^|]+\\|[^|]+\\|"	/* syslog-ng */
 	    ")",
 	REG_NEWLINE|REG_EXTENDED|REG_ICASE,
 	&re_Oops_prefix_pmatch);
@@ -2134,8 +2220,14 @@ int Oops_read(OPTIONS *options)
 		puts(line);
 		lastprint = lineno;
 		if ((start = Oops_eip(text, &string, MAX_STRINGS, ibfd,
-				      options)))
+				      options))) {
+		    const char *ret_addr;
+		    if ((ret_addr = Oops_arm_lr(text, &string, MAX_STRINGS)))
+			Oops_set_arm_lr(ret_addr, &ss_format);
+		    if ((ret_addr = Oops_alpha_ra(text, &string, MAX_STRINGS)))
+			Oops_set_alpha_ra(ret_addr, &ss_format);
 		    Oops_set_eip(start, &eip, &ss_format, me, ibfd, options);
+		}
 		if (Oops_eip_alpha_spinlock(text, &string, MAX_STRINGS,
 					    options)) {
 		    /* Set the eip and previous user from the alpha spinlock
